# Pymasep v0.1

Python MultiAgent System Engine Plateform.

This library is used to create (simple) games or Markov games for reinforcement learning. See https://gitlab.com/jlaumonier/pymas-examples and https://gitlab.com/jlaumonier/encartgames for examples of this library.
It is mainly a tool for proof of concepts and improving my development skills.

see https://pymasep.readthedocs.io for complete documentation

Do not hesitate to comment/open issues if you think this tool can be more helpful.